# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/userroleclass/v1/userroleclass.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/userroleclass/v1/userroleclass.proto\x12\x37github.com.metaprov.modelaapi.services.userroleclass.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\x88\x02\n\x1aListUserRoleClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12o\n\x06labels\x18\x02 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x1bListUserRoleClassesResponse\x12W\n\x05roles\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClassList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15UserRoleClassResponse\"p\n\x1a\x43reateUserRoleClassRequest\x12R\n\x04role\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClass\"\x1d\n\x1b\x43reateUserRoleClassResponse\"\xa1\x01\n\x1aUpdateUserRoleClassRequest\x12R\n\x04role\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClass\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateUserRoleClassResponse\":\n\x17GetUserRoleClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x18GetUserRoleClassResponse\x12R\n\x04role\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.UserRoleClass\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteUserRoleClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteUserRoleClassResponse\"\x1d\n\x1bUserRoleClassCreateResponse\"N\n\x19UserRoleClassLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"+\n\x1aUserRoleClassLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t2\xd4\t\n\x14UserRoleClassService\x12\xe9\x01\n\x13ListUserRoleClasses\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/userroleclasses/{namespace}\x12\xe0\x01\n\x13\x43reateUserRoleClass\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/userroleclasses:\x01*\x12\xe7\x01\n\x10GetUserRoleClass\x12P.github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassRequest\x1aQ.github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/userroleclasses/{namespace}/{name}\x12\x8f\x02\n\x13UpdateUserRoleClass\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassResponse\"M\x82\xd3\xe4\x93\x02G\x1a\x42/v1/userroleclasses/{role.metadata.namespace}/{role.metadata.name}:\x01*\x12\xf0\x01\n\x13\x44\x65leteUserRoleClass\x12S.github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassRequest\x1aT.github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassResponse\".\x82\xd3\xe4\x93\x02(*&/v1/userroleclasses/{namespace}/{name}B9Z7github.com/metaprov/modelaapi/services/userroleclass/v1b\x06proto3')



_LISTUSERROLECLASSESREQUEST = DESCRIPTOR.message_types_by_name['ListUserRoleClassesRequest']
_LISTUSERROLECLASSESREQUEST_LABELSENTRY = _LISTUSERROLECLASSESREQUEST.nested_types_by_name['LabelsEntry']
_LISTUSERROLECLASSESRESPONSE = DESCRIPTOR.message_types_by_name['ListUserRoleClassesResponse']
_USERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['UserRoleClassResponse']
_CREATEUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['CreateUserRoleClassRequest']
_CREATEUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['CreateUserRoleClassResponse']
_UPDATEUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserRoleClassRequest']
_UPDATEUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateUserRoleClassResponse']
_GETUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['GetUserRoleClassRequest']
_GETUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['GetUserRoleClassResponse']
_DELETEUSERROLECLASSREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserRoleClassRequest']
_DELETEUSERROLECLASSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteUserRoleClassResponse']
_USERROLECLASSCREATERESPONSE = DESCRIPTOR.message_types_by_name['UserRoleClassCreateResponse']
_USERROLECLASSLOGINREQUEST = DESCRIPTOR.message_types_by_name['UserRoleClassLoginRequest']
_USERROLECLASSLOGINRESPONSE = DESCRIPTOR.message_types_by_name['UserRoleClassLoginResponse']
ListUserRoleClassesRequest = _reflection.GeneratedProtocolMessageType('ListUserRoleClassesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTUSERROLECLASSESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTUSERROLECLASSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesRequest)
  })
_sym_db.RegisterMessage(ListUserRoleClassesRequest)
_sym_db.RegisterMessage(ListUserRoleClassesRequest.LabelsEntry)

ListUserRoleClassesResponse = _reflection.GeneratedProtocolMessageType('ListUserRoleClassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERROLECLASSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.ListUserRoleClassesResponse)
  })
_sym_db.RegisterMessage(ListUserRoleClassesResponse)

UserRoleClassResponse = _reflection.GeneratedProtocolMessageType('UserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassResponse)
  })
_sym_db.RegisterMessage(UserRoleClassResponse)

CreateUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('CreateUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassRequest)
  })
_sym_db.RegisterMessage(CreateUserRoleClassRequest)

CreateUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('CreateUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.CreateUserRoleClassResponse)
  })
_sym_db.RegisterMessage(CreateUserRoleClassResponse)

UpdateUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('UpdateUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassRequest)
  })
_sym_db.RegisterMessage(UpdateUserRoleClassRequest)

UpdateUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('UpdateUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UpdateUserRoleClassResponse)
  })
_sym_db.RegisterMessage(UpdateUserRoleClassResponse)

GetUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('GetUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassRequest)
  })
_sym_db.RegisterMessage(GetUserRoleClassRequest)

GetUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('GetUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.GetUserRoleClassResponse)
  })
_sym_db.RegisterMessage(GetUserRoleClassResponse)

DeleteUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassRequest)
  })
_sym_db.RegisterMessage(DeleteUserRoleClassRequest)

DeleteUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('DeleteUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.DeleteUserRoleClassResponse)
  })
_sym_db.RegisterMessage(DeleteUserRoleClassResponse)

UserRoleClassCreateResponse = _reflection.GeneratedProtocolMessageType('UserRoleClassCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassCreateResponse)
  })
_sym_db.RegisterMessage(UserRoleClassCreateResponse)

UserRoleClassLoginRequest = _reflection.GeneratedProtocolMessageType('UserRoleClassLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassLoginRequest)
  })
_sym_db.RegisterMessage(UserRoleClassLoginRequest)

UserRoleClassLoginResponse = _reflection.GeneratedProtocolMessageType('UserRoleClassLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERROLECLASSLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.userroleclass.v1.userroleclass_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassLoginResponse)
  })
_sym_db.RegisterMessage(UserRoleClassLoginResponse)

_USERROLECLASSSERVICE = DESCRIPTOR.services_by_name['UserRoleClassService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/userroleclass/v1'
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._options = None
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _USERROLECLASSSERVICE.methods_by_name['ListUserRoleClasses']._options = None
  _USERROLECLASSSERVICE.methods_by_name['ListUserRoleClasses']._serialized_options = b'\202\323\344\223\002!\022\037/v1/userroleclasses/{namespace}'
  _USERROLECLASSSERVICE.methods_by_name['CreateUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['CreateUserRoleClass']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/userroleclasses:\001*'
  _USERROLECLASSSERVICE.methods_by_name['GetUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['GetUserRoleClass']._serialized_options = b'\202\323\344\223\002(\022&/v1/userroleclasses/{namespace}/{name}'
  _USERROLECLASSSERVICE.methods_by_name['UpdateUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['UpdateUserRoleClass']._serialized_options = b'\202\323\344\223\002G\032B/v1/userroleclasses/{role.metadata.namespace}/{role.metadata.name}:\001*'
  _USERROLECLASSSERVICE.methods_by_name['DeleteUserRoleClass']._options = None
  _USERROLECLASSSERVICE.methods_by_name['DeleteUserRoleClass']._serialized_options = b'\202\323\344\223\002(*&/v1/userroleclasses/{namespace}/{name}'
  _LISTUSERROLECLASSESREQUEST._serialized_start=335
  _LISTUSERROLECLASSESREQUEST._serialized_end=599
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._serialized_start=554
  _LISTUSERROLECLASSESREQUEST_LABELSENTRY._serialized_end=599
  _LISTUSERROLECLASSESRESPONSE._serialized_start=602
  _LISTUSERROLECLASSESRESPONSE._serialized_end=745
  _USERROLECLASSRESPONSE._serialized_start=747
  _USERROLECLASSRESPONSE._serialized_end=770
  _CREATEUSERROLECLASSREQUEST._serialized_start=772
  _CREATEUSERROLECLASSREQUEST._serialized_end=884
  _CREATEUSERROLECLASSRESPONSE._serialized_start=886
  _CREATEUSERROLECLASSRESPONSE._serialized_end=915
  _UPDATEUSERROLECLASSREQUEST._serialized_start=918
  _UPDATEUSERROLECLASSREQUEST._serialized_end=1079
  _UPDATEUSERROLECLASSRESPONSE._serialized_start=1081
  _UPDATEUSERROLECLASSRESPONSE._serialized_end=1110
  _GETUSERROLECLASSREQUEST._serialized_start=1112
  _GETUSERROLECLASSREQUEST._serialized_end=1170
  _GETUSERROLECLASSRESPONSE._serialized_start=1172
  _GETUSERROLECLASSRESPONSE._serialized_end=1296
  _DELETEUSERROLECLASSREQUEST._serialized_start=1298
  _DELETEUSERROLECLASSREQUEST._serialized_end=1359
  _DELETEUSERROLECLASSRESPONSE._serialized_start=1361
  _DELETEUSERROLECLASSRESPONSE._serialized_end=1390
  _USERROLECLASSCREATERESPONSE._serialized_start=1392
  _USERROLECLASSCREATERESPONSE._serialized_end=1421
  _USERROLECLASSLOGINREQUEST._serialized_start=1423
  _USERROLECLASSLOGINREQUEST._serialized_end=1501
  _USERROLECLASSLOGINRESPONSE._serialized_start=1503
  _USERROLECLASSLOGINRESPONSE._serialized_end=1546
  _USERROLECLASSSERVICE._serialized_start=1549
  _USERROLECLASSSERVICE._serialized_end=2785
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataproduct/v1/dataproduct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/services/dataproduct/v1/dataproduct.proto\x12\x35github.com.metaprov.modelaapi.services.dataproduct.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\x80\x02\n\x17ListDataProductsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.dataproduct.v1.ListDataProductsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x18ListDataProductsResponse\x12[\n\x0c\x64\x61taproducts\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"r\n\x18\x43reateDataProductRequest\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x1b\n\x19\x43reateDataProductResponse\"\xa2\x01\n\x18UpdateDataProductRequest\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1b\n\x19UpdateDataProductResponse\"8\n\x15GetDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9a\x04\n\x16GetDataProductResponse\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12L\n\x06\x61lerts\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12O\n\x08\x64\x61tasets\x18\x03 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12P\n\x07studies\x18\x04 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12O\n\x06models\x18\x05 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12X\n\npredictors\x18\x06 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x0c\n\x04yaml\x18\x07 \x01(\t\";\n\x18\x44\x65leteDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteDataProductResponse2\x9c\t\n\x12\x44\x61taProductService\x12\xd9\x01\n\x10ListDataProducts\x12N.github.com.metaprov.modelaapi.services.dataproduct.v1.ListDataProductsRequest\x1aO.github.com.metaprov.modelaapi.services.dataproduct.v1.ListDataProductsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/dataproducts/{namespace}\x12\xd3\x01\n\x11\x43reateDataProduct\x12O.github.com.metaprov.modelaapi.services.dataproduct.v1.CreateDataProductRequest\x1aP.github.com.metaprov.modelaapi.services.dataproduct.v1.CreateDataProductResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/dataproducts:\x01*\x12\xda\x01\n\x0eGetDataProduct\x12L.github.com.metaprov.modelaapi.services.dataproduct.v1.GetDataProductRequest\x1aM.github.com.metaprov.modelaapi.services.dataproduct.v1.GetDataProductResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/dataproducts/{namespace}/{name}\x12\x90\x02\n\x11UpdateDataProduct\x12O.github.com.metaprov.modelaapi.services.dataproduct.v1.UpdateDataProductRequest\x1aP.github.com.metaprov.modelaapi.services.dataproduct.v1.UpdateDataProductResponse\"X\x82\xd3\xe4\x93\x02R\x1aM/v1/dataproducts/{dataproduct.metadata.namespace}/{dataproduct.metadata.name}:\x01*\x12\xe3\x01\n\x11\x44\x65leteDataProduct\x12O.github.com.metaprov.modelaapi.services.dataproduct.v1.DeleteDataProductRequest\x1aP.github.com.metaprov.modelaapi.services.dataproduct.v1.DeleteDataProductResponse\"+\x82\xd3\xe4\x93\x02%*#/v1/dataproducts/{namespace}/{name}B7Z5github.com/metaprov/modelaapi/services/dataproduct/v1b\x06proto3')



_LISTDATAPRODUCTSREQUEST = DESCRIPTOR.message_types_by_name['ListDataProductsRequest']
_LISTDATAPRODUCTSREQUEST_LABELSENTRY = _LISTDATAPRODUCTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAPRODUCTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataProductsResponse']
_CREATEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['CreateDataProductRequest']
_CREATEDATAPRODUCTRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataProductResponse']
_UPDATEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataProductRequest']
_UPDATEDATAPRODUCTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataProductResponse']
_GETDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['GetDataProductRequest']
_GETDATAPRODUCTRESPONSE = DESCRIPTOR.message_types_by_name['GetDataProductResponse']
_DELETEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataProductRequest']
_DELETEDATAPRODUCTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataProductResponse']
ListDataProductsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPRODUCTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.ListDataProductsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPRODUCTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.ListDataProductsRequest)
  })
_sym_db.RegisterMessage(ListDataProductsRequest)
_sym_db.RegisterMessage(ListDataProductsRequest.LabelsEntry)

ListDataProductsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.ListDataProductsResponse)
  })
_sym_db.RegisterMessage(ListDataProductsResponse)

CreateDataProductRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.CreateDataProductRequest)
  })
_sym_db.RegisterMessage(CreateDataProductRequest)

CreateDataProductResponse = _reflection.GeneratedProtocolMessageType('CreateDataProductResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.CreateDataProductResponse)
  })
_sym_db.RegisterMessage(CreateDataProductResponse)

UpdateDataProductRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.UpdateDataProductRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductRequest)

UpdateDataProductResponse = _reflection.GeneratedProtocolMessageType('UpdateDataProductResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.UpdateDataProductResponse)
  })
_sym_db.RegisterMessage(UpdateDataProductResponse)

GetDataProductRequest = _reflection.GeneratedProtocolMessageType('GetDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.GetDataProductRequest)
  })
_sym_db.RegisterMessage(GetDataProductRequest)

GetDataProductResponse = _reflection.GeneratedProtocolMessageType('GetDataProductResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.GetDataProductResponse)
  })
_sym_db.RegisterMessage(GetDataProductResponse)

DeleteDataProductRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.DeleteDataProductRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductRequest)

DeleteDataProductResponse = _reflection.GeneratedProtocolMessageType('DeleteDataProductResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataproduct.v1.dataproduct_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataproduct.v1.DeleteDataProductResponse)
  })
_sym_db.RegisterMessage(DeleteDataProductResponse)

_DATAPRODUCTSERVICE = DESCRIPTOR.services_by_name['DataProductService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/metaprov/modelaapi/services/dataproduct/v1'
  _LISTDATAPRODUCTSREQUEST_LABELSENTRY._options = None
  _LISTDATAPRODUCTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAPRODUCTSERVICE.methods_by_name['ListDataProducts']._options = None
  _DATAPRODUCTSERVICE.methods_by_name['ListDataProducts']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/dataproducts/{namespace}'
  _DATAPRODUCTSERVICE.methods_by_name['CreateDataProduct']._options = None
  _DATAPRODUCTSERVICE.methods_by_name['CreateDataProduct']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/dataproducts:\001*'
  _DATAPRODUCTSERVICE.methods_by_name['GetDataProduct']._options = None
  _DATAPRODUCTSERVICE.methods_by_name['GetDataProduct']._serialized_options = b'\202\323\344\223\002%\022#/v1/dataproducts/{namespace}/{name}'
  _DATAPRODUCTSERVICE.methods_by_name['UpdateDataProduct']._options = None
  _DATAPRODUCTSERVICE.methods_by_name['UpdateDataProduct']._serialized_options = b'\202\323\344\223\002R\032M/v1/dataproducts/{dataproduct.metadata.namespace}/{dataproduct.metadata.name}:\001*'
  _DATAPRODUCTSERVICE.methods_by_name['DeleteDataProduct']._options = None
  _DATAPRODUCTSERVICE.methods_by_name['DeleteDataProduct']._serialized_options = b'\202\323\344\223\002%*#/v1/dataproducts/{namespace}/{name}'
  _LISTDATAPRODUCTSREQUEST._serialized_start=485
  _LISTDATAPRODUCTSREQUEST._serialized_end=741
  _LISTDATAPRODUCTSREQUEST_LABELSENTRY._serialized_start=696
  _LISTDATAPRODUCTSREQUEST_LABELSENTRY._serialized_end=741
  _LISTDATAPRODUCTSRESPONSE._serialized_start=744
  _LISTDATAPRODUCTSRESPONSE._serialized_end=888
  _CREATEDATAPRODUCTREQUEST._serialized_start=890
  _CREATEDATAPRODUCTREQUEST._serialized_end=1004
  _CREATEDATAPRODUCTRESPONSE._serialized_start=1006
  _CREATEDATAPRODUCTRESPONSE._serialized_end=1033
  _UPDATEDATAPRODUCTREQUEST._serialized_start=1036
  _UPDATEDATAPRODUCTREQUEST._serialized_end=1198
  _UPDATEDATAPRODUCTRESPONSE._serialized_start=1200
  _UPDATEDATAPRODUCTRESPONSE._serialized_end=1227
  _GETDATAPRODUCTREQUEST._serialized_start=1229
  _GETDATAPRODUCTREQUEST._serialized_end=1285
  _GETDATAPRODUCTRESPONSE._serialized_start=1288
  _GETDATAPRODUCTRESPONSE._serialized_end=1826
  _DELETEDATAPRODUCTREQUEST._serialized_start=1828
  _DELETEDATAPRODUCTREQUEST._serialized_end=1887
  _DELETEDATAPRODUCTRESPONSE._serialized_start=1889
  _DELETEDATAPRODUCTRESPONSE._serialized_end=1916
  _DATAPRODUCTSERVICE._serialized_start=1919
  _DATAPRODUCTSERVICE._serialized_end=3099
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.predictor.v1 import predictor_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2


class PredictorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPredictors = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/ListPredictors',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.ListPredictorsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.ListPredictorsResponse.FromString,
                )
        self.CreatePredictor = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/CreatePredictor',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.CreatePredictorRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.CreatePredictorResponse.FromString,
                )
        self.GetPredictor = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/GetPredictor',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.GetPredictorRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.GetPredictorResponse.FromString,
                )
        self.UpdatePredictor = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/UpdatePredictor',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.UpdatePredictorRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.UpdatePredictorResponse.FromString,
                )
        self.RollBack = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/RollBack',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.RollbackRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.RollbackResponse.FromString,
                )
        self.DeletePredictor = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/DeletePredictor',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.DeletePredictorRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.DeletePredictorResponse.FromString,
                )
        self.PredictOne = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/PredictOne',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.PredictOneRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.PredictOneResponse.FromString,
                )


class PredictorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPredictors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePredictor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPredictor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePredictor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RollBack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePredictor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PredictOne(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PredictorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPredictors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPredictors,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.ListPredictorsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.ListPredictorsResponse.SerializeToString,
            ),
            'CreatePredictor': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePredictor,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.CreatePredictorRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.CreatePredictorResponse.SerializeToString,
            ),
            'GetPredictor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPredictor,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.GetPredictorRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.GetPredictorResponse.SerializeToString,
            ),
            'UpdatePredictor': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePredictor,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.UpdatePredictorRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.UpdatePredictorResponse.SerializeToString,
            ),
            'RollBack': grpc.unary_unary_rpc_method_handler(
                    servicer.RollBack,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.RollbackRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.RollbackResponse.SerializeToString,
            ),
            'DeletePredictor': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePredictor,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.DeletePredictorRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.DeletePredictorResponse.SerializeToString,
            ),
            'PredictOne': grpc.unary_unary_rpc_method_handler(
                    servicer.PredictOne,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.PredictOneRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.PredictOneResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.predictor.v1.PredictorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PredictorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPredictors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/ListPredictors',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.ListPredictorsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.ListPredictorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePredictor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/CreatePredictor',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.CreatePredictorRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.CreatePredictorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPredictor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/GetPredictor',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.GetPredictorRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.GetPredictorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePredictor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/UpdatePredictor',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.UpdatePredictorRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.UpdatePredictorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RollBack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/RollBack',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.RollbackRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.RollbackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePredictor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/DeletePredictor',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.DeletePredictorRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.DeletePredictorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PredictOne(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictor.v1.PredictorService/PredictOne',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.PredictOneRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictor_dot_v1_dot_predictor__pb2.PredictOneResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWgithub.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto\x12=github.com.metaprov.modelaapi.services.onlinefeaturestored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xbf\x02\n\x14\x43reateFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x03 \x01(\t\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12o\n\x06secret\x18\x05 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x17\n\x15\x43reateFeatureResponse\"0\n\x14\x44\x65leteFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteFeatureResponse\"!\n\x13ListFeaturesRequest\x12\n\n\x02ns\x18\x01 \x01(\t\"n\n\x14ListFeaturesResponse\x12V\n\x0b\x63onnections\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\"}\n\x11GetFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\x12N\n\x07\x66\x65\x61ture\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"d\n\x12GetFeatureResponse\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"+\n\rEnrichRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06record\x18\x02 \x01(\t\",\n\x0e\x45nrichResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06record\x18\x02 \x01(\t\"\xdd\x02\n\x14UpdateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12o\n\x06secret\x18\x07 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x17\n\x15UpdateFeatureResponse2\xf4\x08\n\x19OnlineFeatureStoreService\x12\xbc\x01\n\rCreateFeature\x12S.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest\x1aT.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureResponse\"\x00\x12\xbc\x01\n\rDeleteFeature\x12S.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest\x1aT.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureResponse\"\x00\x12\xb9\x01\n\x0cListFeatures\x12R.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesRequest\x1aS.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesResponse\"\x00\x12\xb3\x01\n\nGetFeature\x12P.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest\x1aQ.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureResponse\"\x00\x12\xbc\x01\n\rUpdateFeature\x12S.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest\x1aT.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureResponse\"\x00\x12\xa7\x01\n\x06\x45nrich\x12L.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest\x1aM.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse\"\x00\x42?Z=github.com/metaprov/modelaapi/services/onlinefeaturestored/v1b\x06proto3')



_CREATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureRequest']
_CREATEFEATUREREQUEST_SECRETENTRY = _CREATEFEATUREREQUEST.nested_types_by_name['SecretEntry']
_CREATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureResponse']
_DELETEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureRequest']
_DELETEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureResponse']
_LISTFEATURESREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesRequest']
_LISTFEATURESRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesResponse']
_GETFEATUREREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureRequest']
_GETFEATURERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureResponse']
_ENRICHREQUEST = DESCRIPTOR.message_types_by_name['EnrichRequest']
_ENRICHRESPONSE = DESCRIPTOR.message_types_by_name['EnrichResponse']
_UPDATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureRequest']
_UPDATEFEATUREREQUEST_SECRETENTRY = _UPDATEFEATUREREQUEST.nested_types_by_name['SecretEntry']
_UPDATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureResponse']
CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)
_sym_db.RegisterMessage(CreateFeatureRequest.SecretEntry)

CreateFeatureResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureResponse)
  })
_sym_db.RegisterMessage(CreateFeatureResponse)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

DeleteFeatureResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureResponse)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

GetFeatureResponse = _reflection.GeneratedProtocolMessageType('GetFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureResponse)
  })
_sym_db.RegisterMessage(GetFeatureResponse)

EnrichRequest = _reflection.GeneratedProtocolMessageType('EnrichRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENRICHREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest)
  })
_sym_db.RegisterMessage(EnrichRequest)

EnrichResponse = _reflection.GeneratedProtocolMessageType('EnrichResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENRICHRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse)
  })
_sym_db.RegisterMessage(EnrichResponse)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)
_sym_db.RegisterMessage(UpdateFeatureRequest.SecretEntry)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)

_ONLINEFEATURESTORESERVICE = DESCRIPTOR.services_by_name['OnlineFeatureStoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/metaprov/modelaapi/services/onlinefeaturestored/v1'
  _CREATEFEATUREREQUEST_SECRETENTRY._options = None
  _CREATEFEATUREREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _UPDATEFEATUREREQUEST_SECRETENTRY._options = None
  _UPDATEFEATUREREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEFEATUREREQUEST._serialized_start=296
  _CREATEFEATUREREQUEST._serialized_end=615
  _CREATEFEATUREREQUEST_SECRETENTRY._serialized_start=570
  _CREATEFEATUREREQUEST_SECRETENTRY._serialized_end=615
  _CREATEFEATURERESPONSE._serialized_start=617
  _CREATEFEATURERESPONSE._serialized_end=640
  _DELETEFEATUREREQUEST._serialized_start=642
  _DELETEFEATUREREQUEST._serialized_end=690
  _DELETEFEATURERESPONSE._serialized_start=692
  _DELETEFEATURERESPONSE._serialized_end=715
  _LISTFEATURESREQUEST._serialized_start=717
  _LISTFEATURESREQUEST._serialized_end=750
  _LISTFEATURESRESPONSE._serialized_start=752
  _LISTFEATURESRESPONSE._serialized_end=862
  _GETFEATUREREQUEST._serialized_start=864
  _GETFEATUREREQUEST._serialized_end=989
  _GETFEATURERESPONSE._serialized_start=991
  _GETFEATURERESPONSE._serialized_end=1091
  _ENRICHREQUEST._serialized_start=1093
  _ENRICHREQUEST._serialized_end=1136
  _ENRICHRESPONSE._serialized_start=1138
  _ENRICHRESPONSE._serialized_end=1182
  _UPDATEFEATUREREQUEST._serialized_start=1185
  _UPDATEFEATUREREQUEST._serialized_end=1534
  _UPDATEFEATUREREQUEST_SECRETENTRY._serialized_start=570
  _UPDATEFEATUREREQUEST_SECRETENTRY._serialized_end=615
  _UPDATEFEATURERESPONSE._serialized_start=1536
  _UPDATEFEATURERESPONSE._serialized_end=1559
  _ONLINEFEATURESTORESERVICE._serialized_start=1562
  _ONLINEFEATURESTORESERVICE._serialized_end=2702
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.virtualvolume.v1 import virtualvolume_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2


class VirtualVolumeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListVirtualVolumes = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/ListVirtualVolumes',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.ListVirtualVolumesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.ListVirtualVolumesResponse.FromString,
                )
        self.CreateVirtualVolume = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/CreateVirtualVolume',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.CreateVirtualVolumeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.CreateVirtualVolumeResponse.FromString,
                )
        self.GetVirtualVolume = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/GetVirtualVolume',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.GetVirtualVolumeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.GetVirtualVolumeResponse.FromString,
                )
        self.UpdateVirtualVolume = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/UpdateVirtualVolume',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.UpdateVirtualVolumeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.UpdateVirtualVolumeResponse.FromString,
                )
        self.DeleteVirtualVolume = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/DeleteVirtualVolume',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.DeleteVirtualVolumeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.DeleteVirtualVolumeResponse.FromString,
                )


class VirtualVolumeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListVirtualVolumes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateVirtualVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtualVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVirtualVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVirtualVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VirtualVolumeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListVirtualVolumes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVirtualVolumes,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.ListVirtualVolumesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.ListVirtualVolumesResponse.SerializeToString,
            ),
            'CreateVirtualVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtualVolume,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.CreateVirtualVolumeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.CreateVirtualVolumeResponse.SerializeToString,
            ),
            'GetVirtualVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtualVolume,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.GetVirtualVolumeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.GetVirtualVolumeResponse.SerializeToString,
            ),
            'UpdateVirtualVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVirtualVolume,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.UpdateVirtualVolumeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.UpdateVirtualVolumeResponse.SerializeToString,
            ),
            'DeleteVirtualVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVirtualVolume,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.DeleteVirtualVolumeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.DeleteVirtualVolumeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VirtualVolumeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListVirtualVolumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/ListVirtualVolumes',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.ListVirtualVolumesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.ListVirtualVolumesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateVirtualVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/CreateVirtualVolume',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.CreateVirtualVolumeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.CreateVirtualVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVirtualVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/GetVirtualVolume',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.GetVirtualVolumeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.GetVirtualVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVirtualVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/UpdateVirtualVolume',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.UpdateVirtualVolumeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.UpdateVirtualVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVirtualVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService/DeleteVirtualVolume',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.DeleteVirtualVolumeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualvolume_dot_v1_dot_virtualvolume__pb2.DeleteVirtualVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.virtualbucket.v1 import virtualbucket_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2


class VirtualBucketServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListVirtualBuckets = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/ListVirtualBuckets',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.ListVirtualBucketsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.ListVirtualBucketsResponse.FromString,
                )
        self.CreateVirtualBucket = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/CreateVirtualBucket',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.CreateVirtualBucketRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.CreateVirtualBucketResponse.FromString,
                )
        self.GetVirtualBucket = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/GetVirtualBucket',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.GetVirtualBucketRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.GetVirtualBucketResponse.FromString,
                )
        self.UpdateVirtualBucket = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/UpdateVirtualBucket',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.UpdateVirtualBucketRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.UpdateVirtualBucketResponse.FromString,
                )
        self.DeleteVirtualBucket = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/DeleteVirtualBucket',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.DeleteVirtualBucketRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.DeleteVirtualBucketResponse.FromString,
                )


class VirtualBucketServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListVirtualBuckets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateVirtualBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtualBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVirtualBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVirtualBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VirtualBucketServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListVirtualBuckets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVirtualBuckets,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.ListVirtualBucketsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.ListVirtualBucketsResponse.SerializeToString,
            ),
            'CreateVirtualBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtualBucket,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.CreateVirtualBucketRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.CreateVirtualBucketResponse.SerializeToString,
            ),
            'GetVirtualBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtualBucket,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.GetVirtualBucketRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.GetVirtualBucketResponse.SerializeToString,
            ),
            'UpdateVirtualBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVirtualBucket,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.UpdateVirtualBucketRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.UpdateVirtualBucketResponse.SerializeToString,
            ),
            'DeleteVirtualBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVirtualBucket,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.DeleteVirtualBucketRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.DeleteVirtualBucketResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VirtualBucketService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListVirtualBuckets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/ListVirtualBuckets',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.ListVirtualBucketsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.ListVirtualBucketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateVirtualBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/CreateVirtualBucket',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.CreateVirtualBucketRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.CreateVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVirtualBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/GetVirtualBucket',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.GetVirtualBucketRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.GetVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVirtualBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/UpdateVirtualBucket',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.UpdateVirtualBucketRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.UpdateVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVirtualBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.virtualbucket.v1.VirtualBucketService/DeleteVirtualBucket',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.DeleteVirtualBucketRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_virtualbucket_dot_v1_dot_virtualbucket__pb2.DeleteVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.webrequest.v1 import webrequest_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2


class WebRequestServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListWebRequests = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/ListWebRequests',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsResponse.FromString,
                )
        self.CreateWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/CreateWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestResponse.FromString,
                )
        self.GetWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/GetWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestResponse.FromString,
                )
        self.UpdateWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/UpdateWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestResponse.FromString,
                )
        self.DeleteWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/DeleteWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestResponse.FromString,
                )
        self.RunWebRequest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/RunWebRequest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestResponse.FromString,
                )


class WebRequestServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListWebRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunWebRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebRequestServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListWebRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWebRequests,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsResponse.SerializeToString,
            ),
            'CreateWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestResponse.SerializeToString,
            ),
            'GetWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestResponse.SerializeToString,
            ),
            'UpdateWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestResponse.SerializeToString,
            ),
            'DeleteWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestResponse.SerializeToString,
            ),
            'RunWebRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.RunWebRequest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WebRequestService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListWebRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/ListWebRequests',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.ListWebRequestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/CreateWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.CreateWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/GetWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.GetWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/UpdateWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.UpdateWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/DeleteWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.DeleteWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunWebRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService/RunWebRequest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequest_dot_v1_dot_webrequest__pb2.RunWebRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featureset/v1/featureset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/featureset/v1/featureset.proto\x12\x34github.com.metaprov.modelaapi.services.featureset.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xfb\x01\n\x15ListFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16ListFeaturesetResponse\x12Y\n\x0b\x66\x65\x61turesets\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturesetList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x17\x43reateFeaturesetRequest\x12T\n\nfeatureset\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x1a\n\x18\x43reateFeaturesetResponse\"\x9f\x01\n\x17UpdateFeaturesetRequest\x12T\n\nfeatureset\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateFeaturesetResponse\"7\n\x14GetFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetFeaturesetResponse\x12T\n\nfeatureset\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteFeaturesetResponse2\xf9\x08\n\x11\x46\x65\x61turesetService\x12\xd1\x01\n\x0fListFeaturesets\x12K.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest\x1aL.github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/featuresets/{namespace}\x12\xcd\x01\n\x10\x43reateFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/featuresets:\x01*\x12\xd4\x01\n\rGetFeatureset\x12J.github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest\x1aK.github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/featuresets/{namespace}/{name}\x12\x88\x02\n\x10UpdateFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/featuresets/{featureset.metadata.namespace}/{featureset.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteFeatureset\x12M.github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest\x1aN.github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/featuresets/{namespace}/{name}B6Z4github.com/metaprov/modelaapi/services/featureset/v1b\x06proto3')



_LISTFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesetRequest']
_LISTFEATURESETREQUEST_LABELSENTRY = _LISTFEATURESETREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesetResponse']
_CREATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturesetRequest']
_CREATEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeaturesetResponse']
_UPDATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturesetRequest']
_UPDATEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeaturesetResponse']
_GETFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturesetRequest']
_GETFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturesetResponse']
_DELETEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturesetRequest']
_DELETEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturesetResponse']
ListFeaturesetRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATURESETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetRequest)
  })
_sym_db.RegisterMessage(ListFeaturesetRequest)
_sym_db.RegisterMessage(ListFeaturesetRequest.LabelsEntry)

ListFeaturesetResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.ListFeaturesetResponse)
  })
_sym_db.RegisterMessage(ListFeaturesetResponse)

CreateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetRequest)
  })
_sym_db.RegisterMessage(CreateFeaturesetRequest)

CreateFeaturesetResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.CreateFeaturesetResponse)
  })
_sym_db.RegisterMessage(CreateFeaturesetResponse)

UpdateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturesetRequest)

UpdateFeaturesetResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.UpdateFeaturesetResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturesetResponse)

GetFeaturesetRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetRequest)

GetFeaturesetResponse = _reflection.GeneratedProtocolMessageType('GetFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.GetFeaturesetResponse)
  })
_sym_db.RegisterMessage(GetFeaturesetResponse)

DeleteFeaturesetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturesetRequest)

DeleteFeaturesetResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featureset.v1.featureset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featureset.v1.DeleteFeaturesetResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturesetResponse)

_FEATURESETSERVICE = DESCRIPTOR.services_by_name['FeaturesetService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/featureset/v1'
  _LISTFEATURESETREQUEST_LABELSENTRY._options = None
  _LISTFEATURESETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATURESETSERVICE.methods_by_name['ListFeaturesets']._options = None
  _FEATURESETSERVICE.methods_by_name['ListFeaturesets']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/featuresets/{namespace}'
  _FEATURESETSERVICE.methods_by_name['CreateFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['CreateFeatureset']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/featuresets:\001*'
  _FEATURESETSERVICE.methods_by_name['GetFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['GetFeatureset']._serialized_options = b'\202\323\344\223\002$\022\"/v1/featuresets/{namespace}/{name}'
  _FEATURESETSERVICE.methods_by_name['UpdateFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['UpdateFeatureset']._serialized_options = b'\202\323\344\223\002O\032J/v1/featuresets/{featureset.metadata.namespace}/{featureset.metadata.name}:\001*'
  _FEATURESETSERVICE.methods_by_name['DeleteFeatureset']._options = None
  _FEATURESETSERVICE.methods_by_name['DeleteFeatureset']._serialized_options = b'\202\323\344\223\002$*\"/v1/featuresets/{namespace}/{name}'
  _LISTFEATURESETREQUEST._serialized_start=262
  _LISTFEATURESETREQUEST._serialized_end=513
  _LISTFEATURESETREQUEST_LABELSENTRY._serialized_start=468
  _LISTFEATURESETREQUEST_LABELSENTRY._serialized_end=513
  _LISTFEATURESETRESPONSE._serialized_start=516
  _LISTFEATURESETRESPONSE._serialized_end=656
  _CREATEFEATURESETREQUEST._serialized_start=658
  _CREATEFEATURESETREQUEST._serialized_end=769
  _CREATEFEATURESETRESPONSE._serialized_start=771
  _CREATEFEATURESETRESPONSE._serialized_end=797
  _UPDATEFEATURESETREQUEST._serialized_start=800
  _UPDATEFEATURESETREQUEST._serialized_end=959
  _UPDATEFEATURESETRESPONSE._serialized_start=961
  _UPDATEFEATURESETRESPONSE._serialized_end=987
  _GETFEATURESETREQUEST._serialized_start=989
  _GETFEATURESETREQUEST._serialized_end=1044
  _GETFEATURESETRESPONSE._serialized_start=1046
  _GETFEATURESETRESPONSE._serialized_end=1169
  _DELETEFEATURESETREQUEST._serialized_start=1171
  _DELETEFEATURESETREQUEST._serialized_end=1229
  _DELETEFEATURESETRESPONSE._serialized_start=1231
  _DELETEFEATURESETRESPONSE._serialized_end=1257
  _FEATURESETSERVICE._serialized_start=1260
  _FEATURESETSERVICE._serialized_end=2405
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelcompilerrun.v1 import modelcompilerrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2


class ModelCompilerRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelCompilerRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/ListModelCompilerRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.ListModelCompilerRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.ListModelCompilerRunsResponse.FromString,
                )
        self.CreateModelCompilerRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/CreateModelCompilerRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.CreateModelCompilerRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.CreateModelCompilerRunResponse.FromString,
                )
        self.GetModelCompilerRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/GetModelCompilerRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.GetModelCompilerRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.GetModelCompilerRunResponse.FromString,
                )
        self.UpdateModelCompilerRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/UpdateModelCompilerRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.UpdateModelCompilerRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.UpdateModelCompilerRunResponse.FromString,
                )
        self.DeleteModelCompilerRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/DeleteModelCompilerRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.DeleteModelCompilerRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.DeleteModelCompilerRunResponse.FromString,
                )


class ModelCompilerRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelCompilerRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelCompilerRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelCompilerRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelCompilerRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelCompilerRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelCompilerRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelCompilerRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelCompilerRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.ListModelCompilerRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.ListModelCompilerRunsResponse.SerializeToString,
            ),
            'CreateModelCompilerRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelCompilerRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.CreateModelCompilerRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.CreateModelCompilerRunResponse.SerializeToString,
            ),
            'GetModelCompilerRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelCompilerRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.GetModelCompilerRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.GetModelCompilerRunResponse.SerializeToString,
            ),
            'UpdateModelCompilerRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelCompilerRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.UpdateModelCompilerRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.UpdateModelCompilerRunResponse.SerializeToString,
            ),
            'DeleteModelCompilerRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelCompilerRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.DeleteModelCompilerRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.DeleteModelCompilerRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelCompilerRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelCompilerRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/ListModelCompilerRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.ListModelCompilerRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.ListModelCompilerRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelCompilerRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/CreateModelCompilerRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.CreateModelCompilerRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.CreateModelCompilerRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelCompilerRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/GetModelCompilerRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.GetModelCompilerRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.GetModelCompilerRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelCompilerRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/UpdateModelCompilerRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.UpdateModelCompilerRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.UpdateModelCompilerRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelCompilerRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService/DeleteModelCompilerRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.DeleteModelCompilerRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelcompilerrun_dot_v1_dot_modelcompilerrun__pb2.DeleteModelCompilerRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
